@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003 - 2014 GraphicsMagick Group
+  Copyright (C) 2003 - 2015 GraphicsMagick Group
   Copyright (C) 2002 ImageMagick Studio
   Copyright 1991-1999 E. I. du Pont de Nemours and Company
  
@@ -522,6 +522,8 @@ typedef struct _ChromaticityInfo
 # define SetYellowSample(q,value) ((q)->blue=(value))
 # define SetBlackSample(q,value) ((q)->opacity=(value))
 
+# define ClearPixelPacket(q) ((q)->red=(q)->green=(q)->blue=(q)->opacity=0)
+
 #endif /* defined(MAGICK_IMPLEMENTATION) */
 
 typedef struct _PixelPacket
@@ -1027,7 +1029,7 @@ extern MagickExport int
 /* Functions which return unsigned int as a True/False boolean value */
 extern MagickExport MagickBool
   IsTaintImage(const Image *),
-  IsSubimage(const char *,const unsigned int);
+  IsSubimage(const char *,const MagickBool);
 
 /* Functions which return unsigned int to indicate operation pass/fail */
 extern MagickExport MagickPassFail
@@ -1042,6 +1044,7 @@ extern MagickExport MagickPassFail
   RemoveDefinitions(const ImageInfo *image_info,const char *options),
   ResetImagePage(Image *image,const char *page),
   SetImage(Image *image,const Quantum),
+  SetImageEx(Image *image,const Quantum opacity,ExceptionInfo *exception),
   SetImageColor(Image *image,const PixelPacket *pixel),
   SetImageColorRegion(Image *image,long x,long y,unsigned long width,
 		      unsigned long height,const PixelPacket *pixel),
